PALM-meteo: palmmeteo_stdplugins.synthetic Namespace Reference

PALM-meteo

Classes | Functions | Variables
palmmeteo_stdplugins.synthetic Namespace Reference

## Classes
class | ProfileInterpolator
class | SyntheticPlugin

## Functions
def | expand (var)
def | stretch_heigts (heights, terrain_ratio, gp0, t0, p_surf, p_trans)

## Variables
| barom_pres = PalmPhysics.barom_lapse0_pres
| barom_gp = PalmPhysics.barom_lapse0_gp
| g = PalmPhysics.g

## Function Documentation

## ◆ expand()

def palmmeteo_stdplugins.synthetic.expand | ( |  | var | ) |

    expand horizontal dimensions and pad at top and bottom

## ◆ stretch_heigts()

def palmmeteo_stdplugins.synthetic.stretch_heigts | ( |  | heights,
|  |  | terrain_ratio,
|  |  | gp0,
|  |  | t0,
|  |  | p_surf,
|  |  | p_trans
| ) |  |

## Variable Documentation

## ◆ barom_gp

palmmeteo_stdplugins.synthetic.barom_gp = PalmPhysics.barom_lapse0_gp

## ◆ barom_pres

palmmeteo_stdplugins.synthetic.barom_pres = PalmPhysics.barom_lapse0_pres

## ◆ g

palmmeteo_stdplugins.synthetic.g = PalmPhysics.g